summaryrefslogtreecommitdiff
path: root/src/console/dlt-control-common.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/console/dlt-control-common.h')
-rw-r--r--src/console/dlt-control-common.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/console/dlt-control-common.h b/src/console/dlt-control-common.h
index d743a81..73a8e21 100644
--- a/src/console/dlt-control-common.h
+++ b/src/console/dlt-control-common.h
@@ -61,8 +61,8 @@ typedef struct
uint32_t size; /**< size of that data */
} DltControlMsgBody;
/* As verbosity, ecuid and timeout are needed during the communication,
* defining getter and setters here.
* Then there is no need to define them in the control's user application.
*/
int get_verbosity(void);
@@ -74,6 +74,9 @@ void set_ecuid(char *);
int get_timeout(void);
void set_timeout(int);
+void set_send_serial_header(const int value);
+void set_resync_serial_header(const int value);
+
/* Parse dlt.conf file and return the value of requested configuration */
int dlt_parse_config_param(char *config_id, char **config_data);
@@ -61,8 +61,8 @@ typedef struct
uint32_t size; /**< size of that data */
} DltControlMsgBody;
-/* As verbosity, ecuid and timeout are needed during the communication,
- * defining getter and setters here.
+/* As verbosity, ecuid, timeout, send_serial_header, resync_serial_header are
+ * needed during the communication, defining getter and setters here.
* Then there is no need to define them in the control's user application.
*/